@@ -8,7 +8,6 @@ getScrResu=function(
   paraJobs,
   refTaxa,
   goodIndeCutPerc=0.33,
-  standardize,
   sequentialRun,
   allFunc=allFunc,
   refReadsThresh,
@@ -29,7 +28,6 @@ getScrResu=function(
                        testCovInNewNam=testCovInNewNam,nRef=nRef,
                        paraJobs=paraJobs,
                        refTaxa=refTaxa,
-                       standardize=standardize,
                        sequentialRun=sequentialRun,
                        allFunc=allFunc,
                        refReadsThresh=refReadsThresh,SDThresh=SDThresh,
